==> free-jqgrid-4.9.2.jar: META-INF/resources/webjars/free-jqgrid/4.9.2/js/i18n/grid.locale-fr.js <==
/**
 * jqGrid French Translation
 * Tony Tomov tony@trirand.com with changes by Laurent Rajchenbach.
 * http://trirand.com/blog/ 
 * Dual licensed under the MIT and GPL licenses:
 * http://www.opensource.org/licenses/mit-license.php
 * http://www.gnu.org/licenses/gpl.html
**/

/*jslint white: true */
/*global jQuery */
(function($){
"use strict";
var locInfo = {
	isRTL: false,
	defaults : {
		recordtext: "Enregistrements {0} - {1} sur {2}",
		emptyrecords: "Aucun enregistrement à afficher",
		loadtext: "Chargement...",
		pgtext : "Page {0} sur {1}",
		pgfirst : "Première Page",
		pglast : "Dernière Page",
		pgnext : "Page Suivante",
		pgprev : "Page Précédente",
		pgrecs : "Enregistrements par page",
		showhide: "Afficher/Masquer le tableau",
		savetext: "Enregistrement..."
	},
	search : {
		caption: "Recherche...",
		Find: "Chercher",
		Reset: "Réinitialiser",
		odata: [{ oper:'eq', text:"égal"},{ oper:'ne', text:"différent"},{ oper:'lt', text:"inférieur"},{ oper:'le', text:"inférieur ou égal"},{ oper:'gt', text:"supérieur"},{ oper:'ge', text:"supérieur ou égal"},{ oper:'bw', text:"commence par"},{ oper:'bn', text:"ne commence pas par"},{ oper:'in', text:"est dans"},{ oper:'ni', text:"n'est pas dans"},{ oper:'ew', text:"finit par"},{ oper:'en', text:"ne finit pas par"},{ oper:'cn', text:"contient"},{ oper:'nc', text:"ne contient pas"},{ oper:'nu', text:"est null"},{ oper:'nn', text:"n'est pas null"}],
		groupOps: [	{ op: "AND", text: "tous" },	{ op: "OR",  text: "au moins un" }	],
		operandTitle : "Cliquer pour sélectionner l'opérateur de recherche.",
		resetTitle : "Vider la valeur de recherche"
	},
	edit : {
		addCaption: "Ajouter",
		editCaption: "Editer",
		bSubmit: "Valider",
		bCancel: "Annuler",
		bClose: "Fermer",
		saveData: "Les données ont changé ! Enregistrer les modifications ?",
		bYes: "Oui",
		bNo: "Non",
		bExit: "Annuler",
		msg: {
			required: "Champ obligatoire",
			number: "Saisissez un nombre correct",
			minValue: "La valeur doit être supérieure ou égale à",
			maxValue: "La valeur doit être inférieure ou égale à",
			email: "n'est pas un email correct",
			integer: "Saisissez un entier correct",
			url: "n'est pas une adresse correcte. Préfixe requis ('http://' or 'https://')",
			nodefined : " n'est pas défini!",
			novalue : " la valeur de retour est requise!",
			customarray : "Une fonction personnalisée devrait retourner un tableau (array)!",
			customfcheck : "Une fonction personnalisée devrait être présente dans le cas d'une vérification personnalisée!"
		}
	},
	view : {
		caption: "Voir les enregistrement",
		bClose: "Fermer"
	},
	del : {
		caption: "Supprimer",
		msg: "Supprimer les enregistrements sélectionnés ?",
		bSubmit: "Supprimer",
		bCancel: "Annuler"
	},
	nav : {
		edittext: "",
		edittitle: "Editer la ligne sélectionnée",
		addtext: "",
		addtitle: "Ajouter une ligne",
		deltext: "",
		deltitle: "Supprimer la ligne sélectionnée",
		searchtext: "",
		searchtitle: "Chercher un enregistrement",
		refreshtext: "",
		refreshtitle: "Recharger le tableau",
		alertcap: "Avertissement",
		alerttext: "Veuillez sélectionner une ligne",
		viewtext: "",
		viewtitle: "Afficher la ligne sélectionnée"
	},
	col : {
		caption: "Afficher/Masquer les colonnes",
		bSubmit: "Valider",
		bCancel: "Annuler"
	},
	errors : {
		errcap : "Erreur",
		nourl : "Aucune adresse n'est paramétrée",
		norecords: "Aucun enregistrement à traiter",
		model : "Nombre de titres (colNames) <> Nombre de données (colModel)!"
	},
	formatter : {
		integer : {thousandsSeparator: " ", defaultValue: '0'},
		number : {decimalSeparator:",", thousandsSeparator: " ", decimalPlaces: 2, defaultValue: '0,00'},
		currency : {decimalSeparator:",", thousandsSeparator: " ", decimalPlaces: 2, prefix: "", suffix:"", defaultValue: '0,00'},
		date : {
			dayNames:   [
				"Dim", "Lun", "Mar", "Mer", "Jeu", "Ven", "Sam",
				"Dimanche", "Lundi", "Mardi", "Mercredi", "Jeudi", "Vendredi", "Samedi"
			],
			monthNames: [
				"Jan", "Fév", "Mar", "Avr", "Mai", "Jui", "Jul", "Aou", "Sep", "Oct", "Nov", "Déc",
				"Janvier", "Février", "Mars", "Avril", "Mai", "Juin", "Juillet", "Aout", "Septembre", "Octobre", "Novembre", "Décembre"
			],
			AmPm : ["am","pm","AM","PM"],
			S: function (j) {
				return j === 1 ? 'er' : 'e';
			},
			srcformat: 'Y-m-d',
			newformat: 'd/m/Y',
			masks : {
				ShortDate: "j/n/Y",
				LongDate: "l j n F Y",
				FullDateTime: "l j n F Y H:i:s",
				MonthDay: "j F",
				ShortTime: "H:i",
				LongTime: "H:i:s",
				YearMonth: "F Y"
			}
		}
	}
};
$.jgrid = $.jgrid || {};
$.extend(true, $.jgrid, {
	defaults: {
		locale: "fr-FR"
	},
	locales: {
		// In general the property name is free, but it's recommended to use the names based on
		// http://www.iana.org/assignments/language-subtag-registry/language-subtag-registry
		// http://rishida.net/utils/subtags/ and RFC 5646. See Appendix A of RFC 5646 for examples.
		// One can use the lang attribute to specify language tags in HTML, and the xml:lang attribute for XML
		// if it exists. See http://www.w3.org/International/articles/language-tags/#extlang
		fr: $.extend({}, locInfo, { name: "français", nameEnglish: "French" }),
		"fr-FR": $.extend({}, locInfo, { name: "français (France)", nameEnglish: "French (France)" })
	}
});
}(jQuery));

==> free-jqgrid-4.11.1.jar: META-INF/resources/webjars/free-jqgrid/4.11.1/js/i18n/grid.locale-fr.js <==
/**
 * @license jqGrid French Translation
 * Tony Tomov tony@trirand.com with changes by Laurent Rajchenbach.
 * http://trirand.com/blog/
 * Dual licensed under the MIT and GPL licenses:
 * http://www.opensource.org/licenses/mit-license.php
 * http://www.gnu.org/licenses/gpl.html
**/

/*jslint white: true */
/*global jQuery */
(function ($) {
"use strict";
var locInfo = {
	isRTL: false,
	defaults: {
		recordtext: "Enregistrements {0} - {1} sur {2}",
		emptyrecords: "Aucun enregistrement à afficher",
		loadtext: "Chargement...",
		pgtext: "Page {0} sur {1}",
		pgfirst: "Première Page",
		pglast: "Dernière Page",
		pgnext: "Page Suivante",
		pgprev: "Page Précédente",
		pgrecs: "Enregistrements par page",
		showhide: "Afficher/Masquer le tableau",
		savetext: "Enregistrement..."
	},
	search: {
		caption: "Recherche...",
		Find: "Chercher",
		Reset: "Réinitialiser",
		odata: [
			{ oper: "eq", text: "égal" },
			{ oper: "ne", text: "différent" },
			{ oper: "lt", text: "inférieur" },
			{ oper: "le", text: "inférieur ou égal" },
			{ oper: "gt", text: "supérieur" },
			{ oper: "ge", text: "supérieur ou égal" },
			{ oper: "bw", text: "commence par" },
			{ oper: "bn", text: "ne commence pas par" },
			{ oper: "in", text: "est dans" },
			{ oper: "ni", text: "n'est pas dans" },
			{ oper: "ew", text: "finit par" },
			{ oper: "en", text: "ne finit pas par" },
			{ oper: "cn", text: "contient" },
			{ oper: "nc", text: "ne contient pas" },
			{ oper: "nu", text: "est null" },
			{ oper: "nn", text: "n'est pas null" }
		],
		groupOps: [
			{ op: "AND", text: "tous" },
			{ op: "OR",  text: "au moins un" }
		],
		operandTitle: "Cliquer pour sélectionner l'opérateur de recherche.",
		resetTitle: "Vider la valeur de recherche"
	},
	edit: {
		addCaption: "Ajouter",
		editCaption: "Editer",
		bSubmit: "Valider",
		bCancel: "Annuler",
		bClose: "Fermer",
		saveData: "Les données ont changé ! Enregistrer les modifications ?",
		bYes: "Oui",
		bNo: "Non",
		bExit: "Annuler",
		msg: {
			required: "Champ obligatoire",
			number: "Saisissez un nombre correct",
			minValue: "La valeur doit être supérieure ou égale à",
			maxValue: "La valeur doit être inférieure ou égale à",
			email: "n'est pas un email correct",
			integer: "Saisissez un entier correct",
			url: "n'est pas une adresse correcte. Préfixe requis ('http://' or 'https://')",
			nodefined: " n'est pas défini!",
			novalue: " la valeur de retour est requise!",
			customarray: "Une fonction personnalisée devrait retourner un tableau (array)!",
			customfcheck: "Une fonction personnalisée devrait être présente dans le cas d'une vérification personnalisée!"
		}
	},
	view: {
		caption: "Voir les enregistrement",
		bClose: "Fermer"
	},
	del: {
		caption: "Supprimer",
		msg: "Supprimer les enregistrements sélectionnés ?",
		bSubmit: "Supprimer",
		bCancel: "Annuler"
	},
	nav: {
		edittext: "",
		edittitle: "Editer la ligne sélectionnée",
		addtext: "",
		addtitle: "Ajouter une ligne",
		deltext: "",
		deltitle: "Supprimer la ligne sélectionnée",
		searchtext: "",
		searchtitle: "Chercher un enregistrement",
		refreshtext: "",
		refreshtitle: "Recharger le tableau",
		alertcap: "Avertissement",
		alerttext: "Veuillez sélectionner une ligne",
		viewtext: "",
		viewtitle: "Afficher la ligne sélectionnée"
	},
	col: {
		caption: "Afficher/Masquer les colonnes",
		bSubmit: "Valider",
		bCancel: "Annuler"
	},
	errors: {
		errcap: "Erreur",
		nourl: "Aucune adresse n'est paramétrée",
		norecords: "Aucun enregistrement à traiter",
		model: "Nombre de titres (colNames) <> Nombre de données (colModel)!"
	},
	formatter: {
		integer: { thousandsSeparator: " ", defaultValue: "0" },
		number: { decimalSeparator: ",", thousandsSeparator: " ", decimalPlaces: 2, defaultValue: "0,00" },
		currency: { decimalSeparator: ",", thousandsSeparator: " ", decimalPlaces: 2, prefix: "", suffix: "", defaultValue: "0,00" },
		date: {
			dayNames: [
				"Dim", "Lun", "Mar", "Mer", "Jeu", "Ven", "Sam",
				"Dimanche", "Lundi", "Mardi", "Mercredi", "Jeudi", "Vendredi", "Samedi"
			],
			monthNames: [
				"Jan", "Fév", "Mar", "Avr", "Mai", "Jui", "Jul", "Aou", "Sep", "Oct", "Nov", "Déc",
				"Janvier", "Février", "Mars", "Avril", "Mai", "Juin", "Juillet", "Aout", "Septembre", "Octobre", "Novembre", "Décembre"
			],
			AmPm: ["am", "pm", "AM", "PM"],
			S: function (j) {
				return j === 1 ? "er" : "e";
			},
			srcformat: "Y-m-d",
			newformat: "d/m/Y",
			masks: {
				ShortDate: "j/n/Y",
				LongDate: "l j n F Y",
				FullDateTime: "l j n F Y H:i:s",
				MonthDay: "j F",
				ShortTime: "H:i",
				LongTime: "H:i:s",
				YearMonth: "F Y"
			}
		}
	}
};
$.jgrid = $.jgrid || {};
$.extend(true, $.jgrid, {
	defaults: {
		locale: "fr-FR"
	},
	locales: {
		// In general the property name is free, but it's recommended to use the names based on
		// http://www.iana.org/assignments/language-subtag-registry/language-subtag-registry
		// http://rishida.net/utils/subtags/ and RFC 5646. See Appendix A of RFC 5646 for examples.
		// One can use the lang attribute to specify language tags in HTML, and the xml:lang attribute for XML
		// if it exists. See http://www.w3.org/International/articles/language-tags/#extlang
		fr: $.extend({}, locInfo, { name: "français", nameEnglish: "French" }),
		"fr-FR": $.extend({}, locInfo, { name: "français (France)", nameEnglish: "French (France)" })
	}
});
}(jQuery));
